import { Divider, Drawer, Grid, List, ListItem, ListItemText, makeStyles } from '@material-ui/core';
import React from 'react';
import SCHBodyIcon from '../svg/SCHBodyIcon';
import { MENU_ITEMS } from './Header';
import WrapperLink from './WrapperLink';

type DrawerMenuProps = {
  open: boolean;
  toggleOpen: () => void;
  handleLogout: () => void;
};

const useStyles = makeStyles((theme) => ({
  item: {
    textAlign: 'center',
    fontWeight: 500,
    color: theme.palette.secondary.main,
    '&:hover': {
      color: theme.palette.text.primary,
      backgroundColor: theme.palette.grey[700],
    },
  },
  grid: {
    marginTop: `${theme.spacing(2)}px`,
    marginBottom: `${theme.spacing(2)}px`,
  },
  list: {
    minWidth: '250px',
  },
}));

const DrawerMenu: React.FC<DrawerMenuProps> = ({ open, toggleOpen, handleLogout }) => {
  const classes = useStyles();
  return (
    <Drawer anchor="left" open={open} onClose={toggleOpen}>
      <div className={classes.list}>
        <Grid className={classes.grid} container justify="center">
          <div>
            <SCHBodyIcon width="64px" height="48px" />
          </div>
        </Grid>
        <List>
          {MENU_ITEMS.map((item) => (
            <WrapperLink key={item.id} to={item.redirectTo}>
              <ListItem className={classes.item}>
                <ListItemText>{item.title}</ListItemText>
              </ListItem>
            </WrapperLink>
          ))}
        </List>
        <Divider />
        <List>
          <ListItem className={classes.item} button onClick={handleLogout}>
            <ListItemText>Kijelentkezés</ListItemText>
          </ListItem>
        </List>
      </div>
    </Drawer>
  );
};

export default DrawerMenu;
